(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     77567,       1554]
NotebookOptionsPosition[     73785,       1476]
NotebookOutlinePosition[     74527,       1501]
CellTagsIndexPosition[     74484,       1498]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Numerical Solution of a Nonlinear Dynamical System 
by a  Collocation Method based on Linear B-spline Basis\
\>", "Title",
 CellChangeTimes->{{3.7329761846030545`*^9, 3.732976272057315*^9}, {
  3.7383779119165616`*^9, 3.738377922685157*^9}, {3.7700088252760625`*^9, 
  3.770008867025441*^9}, {3.770112903358968*^9, 3.7701129304458704`*^9}, {
  3.7701129639608164`*^9, 3.770113015384615*^9}, {3.77012138275284*^9, 
  3.7701213887232637`*^9}, {3.7707210585116653`*^9, 3.770721061433338*^9}, {
  3.7707895078845315`*^9, 3.770789509871065*^9}, {3.772786927671144*^9, 
  3.772786928717947*^9}},ExpressionUUID->"08bc54e3-0efd-4181-97c3-\
954ef553d170"],

Cell["\<\
Author : Francesca Pitolli
References : 
\t1) F. Pitolli, Fractals&Fractionals, 2018
\t2) F. Pitolli, Axioms, 2018
\t3) E. Pellegrino, L. Pezza, F. Pitolli, submitted, 2019
\t4) F. Pitolli, Algorithms, 2019
Version: July, 2019\
\>", "Subsection",
 CellChangeTimes->{{3.7707894744020767`*^9, 3.7707895020411415`*^9}, {
  3.7707895747476063`*^9, 3.770789598990201*^9}, {3.7707896847103443`*^9, 
  3.7707897657896976`*^9}, {3.771221150440767*^9, 3.771221150784493*^9}, {
  3.7712407747423306`*^9, 3.771240785196845*^9}, {3.7739783467649775`*^9, 
  3.773978348736703*^9}},ExpressionUUID->"8eb67413-4316-4e7e-936e-\
ebd3c432a647"],

Cell[CellGroupData[{

Cell["Define the Nonlinear Dynamical System", "Section",
 CellChangeTimes->{{3.7700313214572687`*^9, 3.7700313459886703`*^9}, {
   3.770031871991316*^9, 3.7700318898793063`*^9}, {3.770121638367366*^9, 
   3.7701216486973906`*^9}, 
   3.7713345567657948`*^9},ExpressionUUID->"3346d938-10ac-476f-a592-\
e49966ce9807"],

Cell[CellGroupData[{

Cell["\<\
Test Problems : 
     1) Linear dynamical system
     2) Nonlinear dynamical system\
\>", "Subsubsection",
 CellChangeTimes->{{3.770721548193432*^9, 3.7707216639549294`*^9}, {
   3.7707217199461517`*^9, 3.7707217342877507`*^9}, {3.770721795082534*^9, 
   3.770721816233446*^9}, 3.77072317273954*^9, {3.770808897276702*^9, 
   3.7708089122190022`*^9}},ExpressionUUID->"7f7fc801-0ef6-44ed-b035-\
2de4165f9d0c"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Known", " ", "term", " ", "of", " ", "the", " ", "dynamical", " ", 
    "system"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"y", ",", "z", ",", "w", ",", "F", ",", "JF"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Problem", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Which", "[", 
    RowBox[{
     RowBox[{"Problem", "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"F", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"y", "+", "z", "+", "w"}], ",", 
         RowBox[{
          RowBox[{"-", "y"}], "+", "z", "-", "w"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Gamma", "[", 
            FractionBox["3", "2"], "]"}]}], "w"}]}], "}"}]}], ";"}], ",", " ",
      "\[IndentingNewLine]", 
     RowBox[{"Problem", "\[Equal]", "2"}], ",", 
     RowBox[{
      RowBox[{"F", "=", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"y", "+", "z", "+", 
          RowBox[{"100", 
           SqrtBox["\[Pi]"], 
           RowBox[{"y", "^", "2"}]}], "+", "w"}], ",", 
         RowBox[{
          RowBox[{"-", "y"}], "+", "z", "+", 
          RowBox[{"100", 
           SqrtBox["\[Pi]"], 
           RowBox[{"y", "^", "2"}]}], "-", "w"}], ",", 
         RowBox[{
          RowBox[{"w", "^", "2"}], "-", 
          RowBox[{
           FractionBox["1", "200"], 
           SqrtBox["\[Pi]"], "w"}]}]}], " ", "}"}]}], ";"}]}], 
    "\[IndentingNewLine]", "]"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y", "=", 
     RowBox[{"{", 
      RowBox[{"y", ",", "z", ",", "w"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nF", " ", "=", " ", 
     RowBox[{
      RowBox[{"Dimensions", "[", "F", "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Initial", " ", "conditions"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Clear", "[", "Y0", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y0", "  ", "=", 
     RowBox[{"{", 
      RowBox[{"0.05", ",", "0.05", ",", "0.05"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Jacobian", " ", "matrix", " ", "of", " ", "F"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Clear", "[", "JF", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"JF", "=", " ", 
     RowBox[{"Outer", "[", 
      RowBox[{"D", ",", "F", ",", "Y"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"MatrixForm", "[", "JF", "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   StyleBox[
    RowBox[{"(*", " ", 
     RowBox[{
     "Order", " ", "of", " ", "the", " ", "time", " ", "fractional", " ", 
      "derivative", " ", 
      RowBox[{"(", " ", 
       RowBox[{"0", " ", "<", " ", "b", " ", "<", " ", "1"}], ")"}]}], "  ", 
     "*)"}], "Text"], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", " ", "=", " ", "0.5"}], ";"}], "   ", "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.770031353349654*^9, 3.7700313837602196`*^9}, {
   3.770031460332692*^9, 3.770031468192769*^9}, {3.770031902493141*^9, 
   3.7700319172496815`*^9}, {3.7700380669572077`*^9, 
   3.7700380927571564`*^9}, {3.7700388849442854`*^9, 3.770038892104067*^9}, 
   3.770113240064783*^9, {3.7701141957029963`*^9, 3.7701141997681203`*^9}, {
   3.77011815088448*^9, 3.770118185318486*^9}, {3.770209893373869*^9, 
   3.7702099595527377`*^9}, 3.770210215595828*^9, {3.770210338478469*^9, 
   3.770210443472972*^9}, {3.770210494069586*^9, 3.7702104965069504`*^9}, {
   3.7702106860713644`*^9, 3.77021069599772*^9}, {3.7702112212439923`*^9, 
   3.7702112394695997`*^9}, {3.770211282979162*^9, 3.7702113128763647`*^9}, 
   3.770211346952594*^9, {3.770211402997465*^9, 3.770211480161716*^9}, {
   3.7702117150309706`*^9, 3.7702117204084225`*^9}, {3.7702128530600834`*^9, 
   3.7702128647595577`*^9}, {3.770212966577292*^9, 3.770213041134755*^9}, {
   3.7702131326008453`*^9, 3.7702131829571366`*^9}, 3.770213231347263*^9, 
   3.770213371625311*^9, {3.7703463266591115`*^9, 3.7703463283777432`*^9}, {
   3.770523199027164*^9, 3.7705232401503716`*^9}, {3.7705246597881794`*^9, 
   3.770524673692829*^9}, {3.770524932383773*^9, 3.770524955994037*^9}, 
   3.7705250439964333`*^9, {3.7707214744415064`*^9, 3.7707215036321754`*^9}, 
   3.7707215393379297`*^9, {3.770721670415931*^9, 3.7707217162842827`*^9}, {
   3.7707217463485084`*^9, 3.770721782783025*^9}, 3.7707218300700293`*^9, {
   3.7707219868803606`*^9, 3.77072201730836*^9}, {3.7707227117038727`*^9, 
   3.770722711844553*^9}, {3.770722871345714*^9, 3.770722871939421*^9}, {
   3.770722938079894*^9, 3.7707229581085124`*^9}, {3.7707230098553085`*^9, 
   3.7707230686895647`*^9}, {3.770723186799046*^9, 3.7707231969893255`*^9}, {
   3.7707242048025293`*^9, 3.7707242442169204`*^9}, 3.770724904949423*^9, {
   3.77072551299469*^9, 3.770725514069559*^9}, {3.770725933897146*^9, 
   3.7707259646575017`*^9}, {3.7707261060952525`*^9, 3.7707261391567492`*^9}, 
   3.7707295862068834`*^9, {3.7707296256335664`*^9, 3.7707296600799646`*^9}, {
   3.770729694276746*^9, 3.77072970767467*^9}, {3.770808920904333*^9, 
   3.7708089210046096`*^9}, {3.770809142041772*^9, 3.7708093110681715`*^9}, 
   3.770809366582506*^9, 3.7708117459355526`*^9, {3.7708118169891963`*^9, 
   3.7708118353397293`*^9}, {3.770811881387282*^9, 3.7708119284933977`*^9}, {
   3.770811975628111*^9, 3.7708120537132473`*^9}, 3.7708120851680226`*^9, {
   3.7708122255377192`*^9, 3.770812228839554*^9}, {3.7708125049004583`*^9, 
   3.770812505572353*^9}, {3.770812544049058*^9, 3.770812567553773*^9}, {
   3.770813099815648*^9, 3.770813141209054*^9}, 3.7708133941981487`*^9, 
   3.7708134609230056`*^9, {3.7708134975215282`*^9, 3.7708135101683445`*^9}, {
   3.7708135477984*^9, 3.770813547867485*^9}, {3.7708135930163097`*^9, 
   3.7708136355070353`*^9}, {3.770814406368735*^9, 3.7708144210982995`*^9}, {
   3.7708147837517033`*^9, 3.770814849893465*^9}, {3.7709878617115717`*^9, 
   3.77098793396002*^9}, {3.770988236822962*^9, 3.7709882581199355`*^9}, {
   3.770988309244849*^9, 3.7709883533124943`*^9}, {3.7709885790914736`*^9, 
   3.770988606816687*^9}, 3.770988684974889*^9, {3.770989072977721*^9, 
   3.770989096073138*^9}, {3.770989127769946*^9, 3.7709891593163047`*^9}, {
   3.7709893393057394`*^9, 3.7709893403525515`*^9}, {3.77098969941331*^9, 
   3.7709897043992624`*^9}, {3.7709898886756797`*^9, 3.770989895233037*^9}, {
   3.770990010750861*^9, 3.770990019770791*^9}, {3.7709902313757024`*^9, 
   3.770990240956463*^9}, {3.7709904759782014`*^9, 3.7709904806123414`*^9}, {
   3.7709905567106833`*^9, 3.770990563259117*^9}, {3.7709905985911336`*^9, 
   3.7709906529689226`*^9}, {3.770990704804843*^9, 3.7709907075391417`*^9}, {
   3.770991003126425*^9, 3.7709910038452125`*^9}, {3.770991060336686*^9, 
   3.7709910750125694`*^9}, {3.770991111069208*^9, 3.770991154536148*^9}, {
   3.770991223633356*^9, 3.7709912501747246`*^9}, {3.770991290549914*^9, 
   3.7709912943650937`*^9}, {3.7709913595356865`*^9, 
   3.7709913866016326`*^9}, {3.770991428014534*^9, 3.770991434246763*^9}, {
   3.7709915527739363`*^9, 3.770991553555174*^9}, {3.770991595240782*^9, 
   3.770991632851511*^9}, 3.770991874785662*^9, 3.7709919413636703`*^9, 
   3.7710025877298965`*^9, {3.771221283893755*^9, 3.7712212896941047`*^9}, 
   3.771221376032491*^9, {3.7712221085381355`*^9, 3.7712221182403593`*^9}, 
   3.7712383435327344`*^9, 3.7712384093068805`*^9, {3.771240933518044*^9, 
   3.7712409507560186`*^9}, 3.7712462579747257`*^9, 3.771246679798707*^9, {
   3.7713053958343143`*^9, 3.7713053961132727`*^9}, {3.7713054812017717`*^9, 
   3.771305511535426*^9}, {3.771334103064662*^9, 3.77133418277162*^9}, {
   3.7713346458904943`*^9, 3.7713346531937733`*^9}, 3.772790368282112*^9, 
   3.7727943564629097`*^9, {3.772794509489461*^9, 
   3.772794537660373*^9}},ExpressionUUID->"c4a28490-943e-4e01-87fd-\
b4d114987e79"]
}, Open  ]]
}, Open  ]],

Cell["Basis Functions", "Section",
 CellChangeTimes->{{3.7700316804753523`*^9, 
  3.770031689873387*^9}},ExpressionUUID->"38b1aa6d-e12a-4452-a7d9-\
1ae60f60a8a5"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Left-edge boundary function", "Subsubsection"]], \
"Section",
 CellChangeTimes->{{3.770009013574783*^9, 3.7700090355948696`*^9}, 
   3.7700317010214343`*^9, {3.771334573844494*^9, 3.771334578160005*^9}, 
   3.772786948145175*^9},ExpressionUUID->"41864846-420c-4a4e-9165-\
4d49b6ef26f0"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{"Left", " ", "edge", " ", "function"}], "  ", "*)"}], "Text"], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", "N01", "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"N01", "[", "x_", "]"}], ":=", " ", 
    RowBox[{"Piecewise", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "x"}], ")"}], ",", 
        RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "1"}]}], "}"}], 
      "}"}], "]"}]}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.7327958332828574`*^9, 3.7327959289323764`*^9}, {
   3.7327970139579096`*^9, 3.732797016905692*^9}, {3.732974657277021*^9, 
   3.7329746917948346`*^9}, 3.766395654005736*^9, {3.770008914101734*^9, 
   3.77000892016539*^9}, 3.77000899695846*^9, {3.770009082271659*^9, 
   3.7700092722296553`*^9}, {3.771305321501181*^9, 3.7713053283289385`*^9}, {
   3.772786952623315*^9, 3.7727869806161313`*^9}},
 CellLabel->
  "In[754]:=",ExpressionUUID->"5efb9206-c999-44e4-a8f0-54bc292608ac"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Linear B - Spline", "Subsubsection"]], "Section",
 CellChangeTimes->{{3.77000928876782*^9, 3.770009307833645*^9}, {
  3.770520935583925*^9, 3.7705209369744883`*^9}, {3.7727869958609533`*^9, 
  3.772786996876505*^9}},ExpressionUUID->"866dc4bf-d564-4d29-902f-\
491975a1543c"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"Clear", "[", "B1", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"B1", "[", "x_", "]"}], ":=", " ", 
    RowBox[{"Piecewise", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "1"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", "-", "x"}], ",", 
         RowBox[{"1", "\[LessEqual]", "x", "\[LessEqual]", "2"}]}], "}"}]}], 
      "}"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7327958332828574`*^9, 3.7327959289323764`*^9}, {
   3.7327970139579096`*^9, 3.732797016905692*^9}, {3.732974657277021*^9, 
   3.7329746917948346`*^9}, 3.766395654005736*^9, {3.770008914101734*^9, 
   3.77000892016539*^9}, 3.77000899695846*^9, {3.770009082271659*^9, 
   3.7700092843279996`*^9}, {3.772786992595516*^9, 3.7727870395599422`*^9}},
 CellLabel->
  "In[756]:=",ExpressionUUID->"6f683e80-cf87-47fd-a899-0838b9073d9a"]
}, Open  ]],

Cell["Caputo derivative of fractional order b (0 < b < 1) ", "Section",
 CellChangeTimes->{{3.7700382774772763`*^9, 
  3.7700383002580924`*^9}},ExpressionUUID->"31331755-3b67-4704-873b-\
63754bb288ae"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Caputo Derivative of the interior functions\n", \
"Subsection"]], "Section",
 CellChangeTimes->{{3.7700093585262194`*^9, 3.770009369751021*^9}, {
  3.7700094099481707`*^9, 3.7700094985842876`*^9}, {3.7700095374954047`*^9, 
  3.7700095638504267`*^9}, {3.770025155388847*^9, 3.7700251674859667`*^9}, {
  3.770031807049594*^9, 
  3.7700318263557644`*^9}},ExpressionUUID->"b7159cb9-ee6a-4f86-800e-\
9f3cea1d682c"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
    "Derivative", " ", "of", " ", "the", " ", "left", " ", "edge", " ", 
     "function"}], "  ", "*)"}], "Text"], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", "derN01", "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"derN01", "[", 
     RowBox[{"x_", ",", "b_"}], "]"}], ":=", " ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"Gamma", "[", 
       RowBox[{"2", "-", "b"}], "]"}]], 
     RowBox[{"Piecewise", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["x", 
            RowBox[{"1", "-", "b"}]]}], " ", ",", 
          RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "1"}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["x", 
             RowBox[{"1", "-", "b"}]]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x", "-", "1"}], ")"}], 
            RowBox[{"1", "-", "b"}]]}], ",", 
          RowBox[{"1", "\[LessEqual]", "x"}]}], "}"}]}], "}"}], "]"}]}]}], 
   "\n"}]}]], "Input",
 CellChangeTimes->{{3.732797326684782*^9, 3.732797333450175*^9}, {
   3.7327973749286013`*^9, 3.7327973802922487`*^9}, {3.7663956759558477`*^9, 
   3.7663957016067877`*^9}, {3.7663957361443305`*^9, 
   3.7663957468176527`*^9}, {3.77000945671012*^9, 3.7700094580850244`*^9}, {
   3.770009589630072*^9, 3.7700096610435457`*^9}, {3.770009702569661*^9, 
   3.77000973654642*^9}, {3.770031852808979*^9, 3.770031854062791*^9}, {
   3.770038334380395*^9, 3.7700383793665705`*^9}, {3.7700384124335403`*^9, 
   3.7700384207222958`*^9}, {3.7700384535373216`*^9, 
   3.7700384855495963`*^9}, {3.7712285770688767`*^9, 
   3.7712286208736773`*^9}, {3.772787098347805*^9, 3.7727870992539825`*^9}, {
   3.7727891879097185`*^9, 3.7727891960930743`*^9}, {3.7727892408084955`*^9, 
   3.7727892514713936`*^9}, {3.772789292867735*^9, 3.7727892959030004`*^9}, {
   3.772789337024515*^9, 3.7727893842485113`*^9}, 3.772789919388647*^9},
 CellLabel->
  "In[758]:=",ExpressionUUID->"42c55258-8420-42df-a3a2-0a931cffb3c8"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{
   "Caputo", " ", "Derivative", " ", "of", " ", "the", " ", "linear", " ", 
    "B"}], "-", "spline"}], "Subsection"]], "Subsection",
 CellChangeTimes->{{3.732797326684782*^9, 3.732797333450175*^9}, {
  3.7327973749286013`*^9, 3.7327973802922487`*^9}, {3.7663956759558477`*^9, 
  3.7663957016067877`*^9}, {3.7663957361443305`*^9, 3.7663957468176527`*^9}, {
  3.77000945671012*^9, 3.7700094580850244`*^9}, {3.770009589630072*^9, 
  3.7700096610435457`*^9}, {3.770009702569661*^9, 3.77000973654642*^9}, {
  3.770031852808979*^9, 3.770031854062791*^9}, {3.770038334380395*^9, 
  3.7700383793665705`*^9}, {3.7700384124335403`*^9, 3.7700384207222958`*^9}, {
  3.7700384535373216`*^9, 3.7700385091153827`*^9}, {3.770038546291563*^9, 
  3.770038550819002*^9}, {3.7700385917463536`*^9, 3.7700386097711816`*^9}, {
  3.7701131031839657`*^9, 3.77011310429329*^9}, {3.7727893967553644`*^9, 
  3.7727893976888313`*^9}},ExpressionUUID->"ffb41342-358e-4adf-b8d9-\
dc4b8a3bf2d0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "derB1", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"derB1", "[", 
   RowBox[{"x_", ",", "b_"}], "]"}], ":=", " ", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"Gamma", "[", 
     RowBox[{"2", "-", "b"}], "]"}]], 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["x", 
         RowBox[{"1", "-", "b"}]], ",", 
        RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", 
          RowBox[{"1", "-", "b"}]], "-", 
         RowBox[{"2", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "-", "1"}], ")"}], 
           RowBox[{"1", "-", "b"}]]}]}], ",", 
        RowBox[{"1", "\[LessEqual]", "x", "\[LessEqual]", "2"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", 
          RowBox[{"1", "-", "b"}]], "-", 
         RowBox[{"2", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "-", "1"}], ")"}], 
           RowBox[{"1", "-", "b"}]]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"x", "-", "2"}], ")"}], 
          RowBox[{"1", "-", "b"}]]}], ",", 
        RowBox[{"2", "\[LessEqual]", "x"}]}], "}"}]}], "}"}], 
    "]"}]}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.732797326684782*^9, 3.732797333450175*^9}, {
   3.7327973749286013`*^9, 3.7327973802922487`*^9}, {3.7663956759558477`*^9, 
   3.7663957016067877`*^9}, {3.7663957361443305`*^9, 
   3.7663957468176527`*^9}, {3.77000945671012*^9, 3.7700094580850244`*^9}, {
   3.770009589630072*^9, 3.7700096610435457`*^9}, {3.770009702569661*^9, 
   3.77000973654642*^9}, {3.770031852808979*^9, 3.770031854062791*^9}, {
   3.770038334380395*^9, 3.7700383793665705`*^9}, {3.7700384124335403`*^9, 
   3.7700384207222958`*^9}, {3.7700384535373216`*^9, 
   3.7700384966134825`*^9}, {3.770038538754017*^9, 3.7700385413332715`*^9}, {
   3.772789393385292*^9, 3.77278949613957*^9}, {3.7727895598951335`*^9, 
   3.7727896192931895`*^9}, 3.7727899853289633`*^9},
 CellLabel->
  "In[760]:=",ExpressionUUID->"fad9c053-bf9e-41a8-b4ef-bb3deccf2349"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inputs for the collocation method", "Section",
 CellChangeTimes->{{3.7700098049695783`*^9, 3.77000986166208*^9}, 
   3.770520875625696*^9},ExpressionUUID->"cc25ddf5-3300-402a-a06c-\
49166cd17313"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{"Discretization", " ", 
     RowBox[{"interval", ":", " ", 
      RowBox[{"[", 
       RowBox[{"0", ",", "T"}], "]"}]}]}], " ", "*)"}], "Text"], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"T", " ", "=", " ", "8"}], ";"}], "           ", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   StyleBox[
    RowBox[{"(*", " ", 
     RowBox[{"Refinement", "  ", "step"}], " ", "*)"}], "Text"], " ", 
   StyleBox["\[IndentingNewLine]", "Text"], 
   RowBox[{
    RowBox[{"js", " ", "=", " ", "4"}], ";"}], "           ", 
   "\[IndentingNewLine]", 
   RowBox[{"h", " ", "=", " ", 
    FractionBox["1", 
     RowBox[{"2", "^", "js"}]]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   StyleBox[
    RowBox[{"(*", " ", 
     RowBox[{
     "Number", " ", "of", " ", "interior", " ", "basis", " ", "functions"}], 
     " ", "*)"}], "Text"], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Nkint", "=", " ", 
     RowBox[{"T", "/", "h"}]}], ";"}], "        ", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   StyleBox[
    RowBox[{"(*", " ", 
     RowBox[{
     "Number", " ", "of", " ", "left", " ", "edge", " ", "basis", " ", 
      "functions"}], " ", "*)"}], "Text"], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Nkedge", " ", "=", " ", "1"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   StyleBox[
    RowBox[{"(*", " ", 
     RowBox[{"Number", " ", "of", " ", "basis", " ", "functions"}], " ", 
     "*)"}], "Text"], "\[IndentingNewLine]", 
   RowBox[{"Nk", " ", "=", " ", 
    RowBox[{"Nkint", "+", "Nkedge"}]}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.7329463737153482`*^9, 3.732946388903084*^9}, {
   3.732946426404865*^9, 3.7329464824999933`*^9}, {3.7329465453919*^9, 
   3.73294661384756*^9}, 3.7329466707554693`*^9, {3.732946791338911*^9, 
   3.7329467963546047`*^9}, {3.7329468689188385`*^9, 
   3.7329468765918264`*^9}, {3.7329473009147396`*^9, 3.73294734199508*^9}, {
   3.732947448431526*^9, 3.732947459822301*^9}, 3.7329477079037924`*^9, {
   3.732947825940446*^9, 3.7329478277529716`*^9}, {3.7329480899964266`*^9, 
   3.7329481056684933`*^9}, {3.7329484041569147`*^9, 3.732948425047825*^9}, {
   3.7329496142092304`*^9, 3.732949621974961*^9}, {3.732950050204996*^9, 
   3.7329500521581445`*^9}, 3.732950260020342*^9, 3.732950347505905*^9, 
   3.7329504749451303`*^9, 3.732950578837164*^9, {3.7329509884005947`*^9, 
   3.73295125495644*^9}, 3.732951429697994*^9, 3.7329517476872168`*^9, 
   3.732951824547068*^9, {3.732959860054345*^9, 3.7329598659616275`*^9}, {
   3.7329748187445927`*^9, 3.7329748322604046`*^9}, 3.7329754730464816`*^9, {
   3.733019485245093*^9, 3.7330195095478897`*^9}, 3.73302061389432*^9, {
   3.7330210957479053`*^9, 3.7330212293165426`*^9}, {3.73302132303467*^9, 
   3.73302142742671*^9}, {3.733021577788123*^9, 3.7330215842569623`*^9}, {
   3.733021700544223*^9, 3.733021738643512*^9}, {3.7330521663328085`*^9, 
   3.7330521831612196`*^9}, {3.733202955553508*^9, 3.7332029872578897`*^9}, 
   3.7332076038773327`*^9, 3.7332313496704593`*^9, {3.7332313808273935`*^9, 
   3.7332314055934334`*^9}, 3.733234415628301*^9, 3.733234689229744*^9, 
   3.733246569802908*^9, {3.7332469501989927`*^9, 3.733246952949009*^9}, {
   3.7332470127623873`*^9, 3.733247024184425*^9}, {3.7333300281220503`*^9, 
   3.7333300572630925`*^9}, 3.7333323035799522`*^9, {3.7333975918595314`*^9, 
   3.7333975965627446`*^9}, 3.7333976511884403`*^9, 3.733402124233157*^9, 
   3.733402361815279*^9, 3.7334031026509295`*^9, {3.7334048631899185`*^9, 
   3.7334048652836924`*^9}, {3.733405421128248*^9, 3.7334054240814185`*^9}, {
   3.7334066387439737`*^9, 3.733406649775378*^9}, {3.7334075530972347`*^9, 
   3.733407557862932*^9}, {3.7334087283618803`*^9, 3.733408730393161*^9}, {
   3.73340895633389*^9, 3.7334089582401886`*^9}, 3.7334947684573197`*^9, {
   3.7336587090383234`*^9, 3.7336587259006777`*^9}, 3.733658951892728*^9, {
   3.7336606167921896`*^9, 3.733660619354694*^9}, {3.7336607869342813`*^9, 
   3.7336607920436897`*^9}, {3.733660980691304*^9, 3.7336609838007245`*^9}, 
   3.7336615631881557`*^9, {3.7336625346217637`*^9, 3.733662547340666*^9}, 
   3.7336628725080023`*^9, {3.7336629991361585`*^9, 3.733663001339346*^9}, {
   3.7336631841265497`*^9, 3.733663186095332*^9}, {3.733663332583806*^9, 
   3.7336633352557783`*^9}, 3.7336635549485264`*^9, {3.7336637773481817`*^9, 
   3.733663779395088*^9}, {3.7336639046032352`*^9, 3.7336639064313855`*^9}, {
   3.73366400741534*^9, 3.7336640094747*^9}, {3.733826961523944*^9, 
   3.7338269634770703`*^9}, {3.7338270916240096`*^9, 
   3.7338270935927362`*^9}, {3.7338272345671096`*^9, 3.733827236551567*^9}, {
   3.733827353744543*^9, 3.733827360197811*^9}, {3.733827564521987*^9, 
   3.733827566131421*^9}, {3.7338276919056606`*^9, 3.7338276942181897`*^9}, {
   3.73382782165886*^9, 3.733827824033888*^9}, {3.733828115870842*^9, 
   3.733828122120926*^9}, {3.7338288861152353`*^9, 3.733828888818395*^9}, {
   3.7338291036493263`*^9, 3.7338291060868645`*^9}, {3.733829322308461*^9, 
   3.733829326183515*^9}, 3.7338302497304616`*^9, 3.7338337220275583`*^9, 
   3.73383489550751*^9, {3.7338357658032722`*^9, 3.7338357694439754`*^9}, 
   3.7338370319453*^9, {3.7338372817220545`*^9, 3.7338372863939695`*^9}, 
   3.733837464320188*^9, {3.7338376412273455`*^9, 3.7338376456024017`*^9}, 
   3.733837794435171*^9, {3.73544165913554*^9, 3.7354416827901444`*^9}, {
   3.7354417297242956`*^9, 3.735441754144473*^9}, {3.7359055200849247`*^9, 
   3.7359055214129553`*^9}, {3.7359064172657013`*^9, 
   3.7359064280774574`*^9}, {3.7359067118131666`*^9, 3.735906716453464*^9}, {
   3.7359072352330885`*^9, 3.735907238857825*^9}, 3.7359074795265713`*^9, {
   3.7383782069206114`*^9, 3.7383782109046483`*^9}, {3.7383783327867165`*^9, 
   3.738378335411563*^9}, {3.740724977574092*^9, 3.740724980667659*^9}, {
   3.7662000504974165`*^9, 3.766200057700054*^9}, 3.7662001301371183`*^9, 
   3.766213786845583*^9, 3.7662139503676596`*^9, 3.7662143427569447`*^9, 
   3.766214567200307*^9, 3.7662147648306756`*^9, {3.7662149603267856`*^9, 
   3.7662149622339954`*^9}, 3.7662154485001507`*^9, {3.76623641838441*^9, 
   3.7662364185093656`*^9}, 3.76628111023271*^9, {3.7664029094953976`*^9, 
   3.7664029352334785`*^9}, {3.7664031821445713`*^9, 3.766403184847539*^9}, 
   3.766403493591123*^9, 3.766403678772643*^9, {3.766404103654815*^9, 
   3.766404106519535*^9}, 3.766404482610694*^9, 3.766404684278881*^9, {
   3.7664140790390716`*^9, 3.7664140791640635`*^9}, 3.7664146270313225`*^9, {
   3.766414664918171*^9, 3.7664146656365604`*^9}, {3.766414816624692*^9, 
   3.766414816765341*^9}, {3.766415239959873*^9, 3.7664152404285913`*^9}, {
   3.7664562553249164`*^9, 3.7664562618111944`*^9}, 3.7664856013308043`*^9, 
   3.766485780868532*^9, 3.7664862031583195`*^9, 3.7664928491550283`*^9, {
   3.766499286098549*^9, 3.7664992885045795`*^9}, {3.7664994284293814`*^9, 
   3.7664994360560784`*^9}, {3.7665778384368715`*^9, 3.766577858548766*^9}, {
   3.76658109030949*^9, 3.7665810917325087`*^9}, 3.7665819271145334`*^9, 
   3.7665820706281586`*^9, 3.7665822008671627`*^9, {3.766582339635274*^9, 
   3.7665823420257435`*^9}, {3.7665830550462046`*^9, 
   3.7665830814895754`*^9}, {3.766584253049857*^9, 3.766584255057152*^9}, {
   3.766584352466421*^9, 3.7665843584576054`*^9}, {3.7665845403584833`*^9, 
   3.766584548950939*^9}, {3.76658490342124*^9, 3.766584908153576*^9}, {
   3.766585359447499*^9, 3.766585363308777*^9}, {3.766585537446761*^9, 
   3.766585539415371*^9}, {3.7665857320442066`*^9, 3.7665857339190755`*^9}, {
   3.7665859106642866`*^9, 3.7665859129154434`*^9}, {3.766586283939415*^9, 
   3.7665862860174*^9}, {3.7665866392051287`*^9, 3.766586641079998*^9}, {
   3.766586791419592*^9, 3.7665867939525285`*^9}, 3.766586839840575*^9, {
   3.7665869436523485`*^9, 3.766586945877309*^9}, 3.7665869945396895`*^9, 
   3.7666390791857615`*^9, {3.7666396674804225`*^9, 3.766639670714509*^9}, {
   3.7666399197915444`*^9, 3.7666399215747333`*^9}, {3.7666400701537933`*^9, 
   3.7666400760909357`*^9}, {3.7666402436931505`*^9, 3.766640245786815*^9}, {
   3.7666414302457037`*^9, 3.7666414317768126`*^9}, {3.7666417143871574`*^9, 
   3.7666417171387377`*^9}, {3.766641773414995*^9, 3.7666417763535895`*^9}, {
   3.766641958819273*^9, 3.766641962194038*^9}, {3.7666420846473227`*^9, 
   3.766642086834729*^9}, {3.76666956406565*^9, 3.7666695666905007`*^9}, {
   3.766670299733759*^9, 3.7666703029077234`*^9}, {3.7666707048982315`*^9, 
   3.7666707066168995`*^9}, {3.766670856031972*^9, 3.76667085778408*^9}, {
   3.7666722570933833`*^9, 3.766672258874509*^9}, {3.7666726373164654`*^9, 
   3.7666726454745817`*^9}, {3.766672789304294*^9, 3.766672791413554*^9}, {
   3.766672937015271*^9, 3.7666729390620375`*^9}, {3.7667340618818016`*^9, 
   3.7667340649753923`*^9}, {3.7667350279180145`*^9, 
   3.7667350293867164`*^9}, {3.7667357166860924`*^9, 3.76673571851157*^9}, {
   3.770009843254404*^9, 3.7700099432885857`*^9}, {3.7700100089661503`*^9, 
   3.770010022753378*^9}, {3.770010082171525*^9, 3.7700104182223516`*^9}, 
   3.770025209234231*^9, {3.770025955509633*^9, 3.7700259703935523`*^9}, 
   3.7700294264551325`*^9, {3.7700294848969717`*^9, 3.77002952601758*^9}, {
   3.7700295793022375`*^9, 3.7700297575103326`*^9}, {3.7700298130579033`*^9, 
   3.770029851752573*^9}, 3.7700315225885305`*^9, {3.770114316226544*^9, 
   3.7701143487413197`*^9}, {3.770114405594305*^9, 3.770114406141143*^9}, {
   3.770211565832011*^9, 3.770211568631857*^9}, {3.7703515701339865`*^9, 
   3.770351575055574*^9}, {3.770437295452526*^9, 3.77043730108117*^9}, {
   3.770449612232227*^9, 3.770449612466555*^9}, {3.7704688620660124`*^9, 
   3.770468891200824*^9}, {3.770468931435896*^9, 3.770468936763652*^9}, {
   3.770469025764668*^9, 3.770469025874063*^9}, {3.770523673318779*^9, 
   3.7705236830883455`*^9}, 3.770524044085248*^9, {3.7705246822874527`*^9, 
   3.7705246825061874`*^9}, {3.770524775762142*^9, 3.7705247931268144`*^9}, 
   3.7705256558293447`*^9, {3.7705257925359774`*^9, 3.7705258319438424`*^9}, {
   3.7707220717479763`*^9, 3.7707221364659705`*^9}, 3.770723313243943*^9, 
   3.770723388532779*^9, 3.7707234247485385`*^9, 3.7707235426564665`*^9, {
   3.770723768322462*^9, 3.770723781799411*^9}, {3.7707238636476655`*^9, 
   3.770723929001852*^9}, 3.77072414552534*^9, {3.770724889237455*^9, 
   3.7707248898312263`*^9}, {3.7707256337345114`*^9, 3.770725634069195*^9}, 
   3.7707256995456*^9, 3.77072583991963*^9, {3.7707258904330444`*^9, 
   3.770725890542472*^9}, {3.770726005785647*^9, 3.770726014277528*^9}, {
   3.7707261489238377`*^9, 3.770726155771325*^9}, 3.7707262544745054`*^9, 
   3.770726359547053*^9, {3.7707265043884172`*^9, 3.770726506687716*^9}, 
   3.7707266489372263`*^9, 3.7707269618898787`*^9, 3.770727947893364*^9, {
   3.770727999343295*^9, 3.770728007016611*^9}, {3.770728264605571*^9, 
   3.770728265027394*^9}, 3.770728534705223*^9, 3.7707285674353323`*^9, 
   3.7707292881340313`*^9, 3.7707293890699415`*^9, {3.770729459239259*^9, 
   3.770729459364219*^9}, {3.7707297336497173`*^9, 3.7707297342774878`*^9}, {
   3.7707846084921727`*^9, 3.7707846306521792`*^9}, {3.7707855544467783`*^9, 
   3.770785578329708*^9}, {3.770785676493828*^9, 3.7707856768531733`*^9}, {
   3.77078627979015*^9, 3.770786279899515*^9}, 3.770790142912263*^9, {
   3.77081013719751*^9, 3.770810139859212*^9}, {3.770812719894303*^9, 
   3.770812720097475*^9}, {3.7708140931747966`*^9, 3.7708140998024564`*^9}, {
   3.770814262083357*^9, 3.770814262208413*^9}, 3.7708145100607333`*^9, 
   3.7709884415397015`*^9, {3.770989414611371*^9, 3.7709894149235353`*^9}, 
   3.7709896452279797`*^9, 3.770990055575421*^9, {3.770990738935217*^9, 
   3.770990758379534*^9}, 3.7709908159943438`*^9, 3.770991036510612*^9, 
   3.7709914727925625`*^9, 3.770991662959073*^9, 3.770991808374081*^9, {
   3.7709918424465466`*^9, 3.7709918476833105`*^9}, {3.7710026062641525`*^9, 
   3.7710026304277806`*^9}, {3.771221469375576*^9, 3.7712214722816906`*^9}, {
   3.771221600654409*^9, 3.771221601123127*^9}, 3.7712216381764345`*^9, {
   3.7712217759978247`*^9, 3.7712217767790203`*^9}, 3.7712222443019857`*^9, {
   3.771222333028344*^9, 3.7712223335751815`*^9}, 3.7712284667883425`*^9, {
   3.7712399384925222`*^9, 3.771239958651869*^9}, {3.771240024655225*^9, 
   3.771240041780547*^9}, 3.771246899912701*^9, {3.7712470576654205`*^9, 
   3.771247061863417*^9}, 3.7712472226007805`*^9, 3.7712473610401745`*^9, {
   3.771304505527341*^9, 3.771304522753808*^9}, {3.77130659366951*^9, 
   3.7713066182891335`*^9}, 3.7713066485546055`*^9, {3.7713339493596525`*^9, 
   3.77133395114153*^9}, {3.7713344609497833`*^9, 3.7713344674542975`*^9}, {
   3.7713346172663345`*^9, 3.7713346186416426`*^9}, {3.771334685297525*^9, 
   3.7713346863007593`*^9}, {3.7727900165941052`*^9, 3.7727900308289576`*^9}, 
   3.7727943762965784`*^9},
 CellLabel->
  "In[762]:=",ExpressionUUID->"a6f0c34b-7c15-4f53-8b77-46c3cc0cd92c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Collocation Points ", "Section",
 CellChangeTimes->{{3.7329463737153482`*^9, 3.732946388903084*^9}, {
   3.732946426404865*^9, 3.7329464824999933`*^9}, {3.7329465453919*^9, 
   3.73294661384756*^9}, 3.7329466707554693`*^9, {3.732946791338911*^9, 
   3.7329467963546047`*^9}, {3.7329468689188385`*^9, 
   3.7329468765918264`*^9}, {3.7329473009147396`*^9, 3.73294734199508*^9}, {
   3.732947448431526*^9, 3.732947459822301*^9}, 3.7329477079037924`*^9, {
   3.732947825940446*^9, 3.7329478277529716`*^9}, {3.7329480899964266`*^9, 
   3.7329481056684933`*^9}, {3.7329484041569147`*^9, 3.732948425047825*^9}, {
   3.7329496142092304`*^9, 3.732949621974961*^9}, {3.732950050204996*^9, 
   3.7329500521581445`*^9}, 3.732950260020342*^9, 3.732950347505905*^9, 
   3.7329504749451303`*^9, 3.732950578837164*^9, {3.7329509884005947`*^9, 
   3.73295125495644*^9}, 3.732951429697994*^9, 3.7329517476872168`*^9, 
   3.732951824547068*^9, {3.732959860054345*^9, 3.7329598659616275`*^9}, {
   3.7329748187445927`*^9, 3.7329748322604046`*^9}, 3.7329754730464816`*^9, {
   3.733019485245093*^9, 3.7330195095478897`*^9}, 3.73302061389432*^9, {
   3.7700261325339518`*^9, 3.7700261849544044`*^9}, {3.770026382919137*^9, 
   3.770026391579194*^9}, {3.7700293246020803`*^9, 3.7700293260707808`*^9}, {
   3.770113063999061*^9, 3.770113079048859*^9}, 
   3.7707844944758277`*^9},ExpressionUUID->"f9eb6e00-eb9e-40e6-a54d-\
2b6d716dc661"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "TPoints", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dt", " ", "=", " ", 
   FractionBox["h", "2"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Ns", "=", " ", 
  RowBox[{"T", "/", "dt"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TPoints", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"i", " ", "dt"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "Ns"}], "}"}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"Ns", " ", "<", "  ", "Nk"}], ",", " ", 
    RowBox[{
    "Print", "[", "\"\<ERROR: Ns should be greater than or equal to Nk\>\"", 
     "]"}]}], "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.770026420276658*^9, {3.770026451732828*^9, 3.7700265088731203`*^9}, {
   3.7700292998467107`*^9, 3.770029309378662*^9}, {3.770029821872853*^9, 
   3.7700298242689347`*^9}, {3.770029868573114*^9, 3.7700298686824894`*^9}, 
   3.770728016425709*^9, {3.77078444907895*^9, 3.770784450549839*^9}, {
   3.7707844869296694`*^9, 3.770784488507618*^9}, {3.770784529706693*^9, 
   3.770784533831312*^9}, 3.7707846573242655`*^9, {3.7707846890211086`*^9, 
   3.7707846909758787`*^9}, {3.770784753927472*^9, 3.77078476547994*^9}, {
   3.7707847957213426`*^9, 3.7707848572938957`*^9}, 3.770784901118839*^9, {
   3.7707849733567886`*^9, 3.770784973575517*^9}, {3.7707850181476727`*^9, 
   3.770785019960082*^9}, {3.770785052377446*^9, 3.770785080471908*^9}, {
   3.7707851732972937`*^9, 3.7707852394282155`*^9}, 3.770785312302952*^9, {
   3.7707854779495287`*^9, 3.7707855060694804`*^9}, {3.7707856500887823`*^9, 
   3.7707856505418444`*^9}, {3.770785717146598*^9, 3.7707857172716494`*^9}, 
   3.7707858207605066`*^9, {3.7707858720710583`*^9, 3.770785873948672*^9}, {
   3.770785944641621*^9, 3.770785947283701*^9}, {3.770786390962813*^9, 
   3.7707865136790953`*^9}, {3.770786544516303*^9, 3.7707866580316496`*^9}, {
   3.770786726221278*^9, 3.7707868311831045`*^9}, {3.7707868661074286`*^9, 
   3.7707868835824366`*^9}, {3.7707869353687973`*^9, 
   3.7707869656293783`*^9}, {3.7708141078818913`*^9, 3.7708141092411723`*^9}, 
   3.7708141595542817`*^9, {3.770814203120123*^9, 3.7708142236935616`*^9}, {
   3.7708142705072885`*^9, 3.7708142706322803`*^9}, {3.771221826053443*^9, 
   3.7712218792247157`*^9}, {3.7712219220340605`*^9, 3.771221922472783*^9}, {
   3.771222174424306*^9, 3.7712221830978146`*^9}, 3.7712251525929427`*^9, 
   3.77122530222554*^9, {3.7712253445455227`*^9, 3.7712253950841846`*^9}, {
   3.7712254618829937`*^9, 3.7712254624610796`*^9}, {3.771225577079714*^9, 
   3.771225583924328*^9}, {3.7712256354696927`*^9, 3.77122564480352*^9}, {
   3.7712257032301826`*^9, 3.7712257059487453`*^9}, 3.7712282773654594`*^9, {
   3.7712383788649673`*^9, 3.771238379443022*^9}, {3.7712400615818596`*^9, 
   3.7712401720836954`*^9}, {3.7712402410781035`*^9, 3.771240276786837*^9}, 
   3.7712411897851486`*^9, 3.7712469874501*^9, 3.771247070235717*^9, {
   3.77124713333502*^9, 3.771247134178775*^9}, {3.771247193988078*^9, 
   3.7712471945751743`*^9}, {3.7713046039250793`*^9, 
   3.7713046609696927`*^9}, {3.7713048281058073`*^9, 3.771304830215066*^9}, {
   3.7713049080742497`*^9, 3.7713049429556985`*^9}, {3.771334438403389*^9, 
   3.7713344509111385`*^9}, {3.7713347353529673`*^9, 3.7713347497823358`*^9}},
 CellLabel->
  "In[769]:=",ExpressionUUID->"f9441561-30dc-4df7-90e6-9d34f5b66484"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Collocation Matrix for the Cubic B-spline Basis", "Section",
 CellChangeTimes->{
  3.7700291562649727`*^9, {3.7700292709729156`*^9, 3.770029270988554*^9}, {
   3.770029313723184*^9, 3.77002932075596*^9}, 3.7700301462325463`*^9, {
   3.7701130937104545`*^9, 3.770113096587425*^9}, {3.7705209602916126`*^9, 
   3.770520971554036*^9}},ExpressionUUID->"648c2988-bddb-42f7-b1ae-\
eafe61a80c68"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{"Interior", " ", "functions"}], " ", "*)"}], "Text"], 
  StyleBox["\[IndentingNewLine]", "Text"], 
  RowBox[{
   RowBox[{"Clear", "[", "Mcoll0int", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Mcoll0int", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"B1", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"TPoints", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "h"], "-", "k"}], "]"}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2", ",", "Ns"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", 
         RowBox[{"Nkint", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   StyleBox[
    RowBox[{"(*", " ", 
     RowBox[{"Collocation", " ", "matrix"}], " ", "*)"}], "Text"], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Mcoll0", " ", "=", " ", 
     RowBox[{"Transpose", "[", "Mcoll0int", "]"}]}], ";"}], "\n", 
   RowBox[{"Dimensions", "[", "Mcoll0", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Clear", "[", "Mcoll0int", "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.622552237161689*^9, 3.622552278442891*^9, {3.6225523283958826`*^9, 
   3.6225524261769867`*^9}, {3.622552478145616*^9, 3.622552483723732*^9}, 
   3.622552543364295*^9, {3.62256382606121*^9, 3.6225638972026663`*^9}, {
   3.622563949265804*^9, 3.622563977297432*^9}, {3.622564064642305*^9, 
   3.622564102752142*^9}, {3.6225644000996037`*^9, 3.6225644010683765`*^9}, {
   3.6225644361156273`*^9, 3.6225644594753675`*^9}, {3.6225645059446764`*^9, 
   3.6225645184448013`*^9}, {3.62256457653926*^9, 3.6225647609165354`*^9}, {
   3.6225648245267935`*^9, 3.622564905043214*^9}, 3.622564966950308*^9, {
   3.622565004513296*^9, 3.622565043404416*^9}, {3.6226167160513277`*^9, 
   3.622616716692034*^9}, {3.622616932302985*^9, 3.6226169477249565`*^9}, 
   3.6226170021160617`*^9, {3.6228941510271034`*^9, 3.622894167058446*^9}, {
   3.6228942018243675`*^9, 3.622894285840732*^9}, {3.6228944202596426`*^9, 
   3.622894424775295*^9}, {3.6228946028858614`*^9, 3.6228946056827617`*^9}, 
   3.622895579160679*^9, 3.622895671833474*^9, 3.622895837163191*^9, {
   3.623045122469674*^9, 3.6230451723293204`*^9}, 3.6230457426299334`*^9, {
   3.623470420812352*^9, 3.6234704243593397`*^9}, {3.623470683226535*^9, 
   3.6234707008830347`*^9}, {3.6234708914316435`*^9, 3.62347091471307*^9}, {
   3.6234713127325087`*^9, 3.623471335045208*^9}, {3.623471833049987*^9, 
   3.623471860815838*^9}, {3.6234720970682344`*^9, 3.623472113568367*^9}, {
   3.6234732275476217`*^9, 3.623473228219487*^9}, 3.623568344239814*^9, 
   3.6235688107702265`*^9, 3.6235764477529025`*^9, 3.623576535502465*^9, 
   3.6235766015336246`*^9, 3.623576645377178*^9, {3.6237562629655*^9, 
   3.6237562858248353`*^9}, 3.623756411074013*^9, {3.624890019092003*^9, 
   3.6248900467954006`*^9}, {3.6248905335653577`*^9, 3.624890535440315*^9}, {
   3.624962378184225*^9, 3.624962384684263*^9}, 3.626004371637586*^9, 
   3.6260045623882227`*^9, 3.6260049148581047`*^9, {3.6260615731343203`*^9, 
   3.626061578509254*^9}, {3.6265962749628086`*^9, 3.626596283416113*^9}, {
   3.6265964806377954`*^9, 3.626596481278427*^9}, 3.6265965364198246`*^9, 
   3.6265970421143804`*^9, 3.6265976356552887`*^9, 3.6366884998626537`*^9, {
   3.636688820350551*^9, 3.6366888448664446`*^9}, 3.6366896324421053`*^9, {
   3.6366897085054436`*^9, 3.6366897109273443`*^9}, 3.636689777631201*^9, {
   3.6366908283699517`*^9, 3.6366908299480925`*^9}, {3.636691050747398*^9, 
   3.636691053216173*^9}, {3.7328717469476223`*^9, 3.73287178696546*^9}, 
   3.7328718577811136`*^9, {3.7328719243320427`*^9, 3.7328719705669994`*^9}, 
   3.73287207732065*^9, {3.7328721214469175`*^9, 3.7328721264781713`*^9}, {
   3.7328723561126738`*^9, 3.732872380847044*^9}, 3.732872618856084*^9, 
   3.732872876082345*^9, 3.7328729109578023`*^9, 3.732937442018961*^9, 
   3.732937482347664*^9, {3.7329376822253428`*^9, 3.732937689131744*^9}, 
   3.732947817674651*^9, {3.732948068574293*^9, 3.7329480688711195`*^9}, {
   3.7329490314320107`*^9, 3.732949033150733*^9}, {3.732950045158044*^9, 
   3.7329500468143444`*^9}, 3.7329505878998404`*^9, {3.732950941308674*^9, 
   3.7329509706028337`*^9}, {3.7330212178468676`*^9, 
   3.7330212207219095`*^9}, {3.733208802947728*^9, 3.733208807181102*^9}, {
   3.7338274322955575`*^9, 3.73382744023322*^9}, {3.7662371761270266`*^9, 
   3.7662371875207777`*^9}, {3.7662372598242846`*^9, 3.766237295750473*^9}, {
   3.770026203457776*^9, 3.7700262677846537`*^9}, 3.7700265882769365`*^9, {
   3.7700293590316844`*^9, 3.770029369708497*^9}, {3.770029897466545*^9, 
   3.770029903733981*^9}, {3.770029941437387*^9, 3.7700299620314565`*^9}, {
   3.7700300252402925`*^9, 3.7700300256933813`*^9}, {3.770030398921055*^9, 
   3.7700304134546237`*^9}, {3.7700305709276037`*^9, 3.770030601720582*^9}, {
   3.7703501286006527`*^9, 3.770350128678761*^9}, {3.7703521538610225`*^9, 
   3.7703521562671623`*^9}, {3.7703527558620377`*^9, 
   3.7703527579422827`*^9}, {3.770449431641651*^9, 3.77044943186033*^9}, {
   3.7704499563467484`*^9, 3.7704499565030165`*^9}, {3.770810162633648*^9, 
   3.770810167231863*^9}, {3.7713344006940756`*^9, 3.7713344266231613`*^9}, {
   3.771334735368573*^9, 3.771334735368573*^9}, {3.772790049920083*^9, 
   3.7727901043949165`*^9}, {3.772794389356123*^9, 3.772794390659402*^9}},
 CellLabel->
  "In[774]:=",ExpressionUUID->"67e2f0cb-1bd8-4ee3-b2e4-99af1335f701"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Collocation Matrix for the Caputo Derivative of the B-spline Basis\
\>", "Section",
 CellChangeTimes->{{3.7329497782114534`*^9, 3.732949795821067*^9}, {
  3.7700300622380953`*^9, 3.7700301222620487`*^9}, {3.7705209831968594`*^9, 
  3.7705209855261774`*^9}},ExpressionUUID->"b86d5c1c-d494-444b-bf64-\
daac74834407"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
    "Normalization", " ", "factor", " ", "for", " ", "the", " ", 
     "derivative"}], "*)"}], "Input"], 
  StyleBox["\[IndentingNewLine]", "Input"], 
  RowBox[{
   StyleBox[
    RowBox[{
     RowBox[{"normder", " ", "=", " ", 
      RowBox[{"2", "^", 
       RowBox[{"(", 
        RowBox[{"js", " ", "b"}], ")"}]}]}], ";"}], "Input"], 
   "\[IndentingNewLine]", 
   StyleBox["\[IndentingNewLine]", "Text"], 
   StyleBox[
    RowBox[{"(*", " ", 
     RowBox[{"Interior", " ", "functions"}], " ", "*)"}], "Text"], 
   "\[IndentingNewLine]", 
   RowBox[{"Clear", "[", "Mcoll1int", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Mcoll1int", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"normder", " ", 
         RowBox[{"derB1", "[", " ", 
          RowBox[{
           RowBox[{
            FractionBox[
             RowBox[{"TPoints", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "h"], "-", "k"}], ",", "b"}], 
          "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2", ",", "Ns"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", 
         RowBox[{"Nkint", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   StyleBox[
    RowBox[{"(*", " ", 
     RowBox[{"Collocation", " ", "matrix"}], " ", "*)"}], "Text"], "\n", 
   RowBox[{
    RowBox[{"Mcoll1", " ", "=", " ", 
     RowBox[{"Transpose", "[", "Mcoll1int", "]"}]}], ";"}], "\n", 
   RowBox[{"Dimensions", "[", "Mcoll1", "]"}], "\n", 
   RowBox[{"Clear", "[", "Mcoll1int", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.73287208199259*^9, 3.732872151150799*^9}, {
   3.732874097269004*^9, 3.73287409973779*^9}, {3.732937925478694*^9, 
   3.732937938635084*^9}, {3.7329496853195696`*^9, 3.7329496885071173`*^9}, {
   3.732949801258648*^9, 3.7329498014774003`*^9}, {3.7329500943774614`*^9, 
   3.7329500968774967`*^9}, 3.7329513114420404`*^9, {3.7329516632022758`*^9, 
   3.732951669874247*^9}, {3.733021260770903*^9, 3.7330212763336124`*^9}, {
   3.733021447317604*^9, 3.7330214563177347`*^9}, {3.7332088486052885`*^9, 
   3.7332088543241167`*^9}, {3.7338274112943387`*^9, 3.733827419200737*^9}, {
   3.766237311029952*^9, 3.7662373320574193`*^9}, {3.77003017664081*^9, 
   3.770030292073743*^9}, {3.7700303768798695`*^9, 3.770030385271948*^9}, {
   3.770030480999263*^9, 3.7700305430384*^9}, {3.7700306414738636`*^9, 
   3.770030656384918*^9}, {3.770030690598873*^9, 3.7700307278127084`*^9}, {
   3.770113134696251*^9, 3.7701131569823*^9}, {3.770118222072892*^9, 
   3.770118225150796*^9}, {3.770350141104211*^9, 3.770350141416689*^9}, {
   3.770352178731577*^9, 3.7703521809240246`*^9}, {3.7703527348107166`*^9, 
   3.770352737341789*^9}, {3.7704494471330395`*^9, 3.7704494473517885`*^9}, {
   3.7704499722411346`*^9, 3.7704499723973722`*^9}, {3.7708101738943267`*^9, 
   3.770810179114396*^9}, {3.771228592022174*^9, 3.771228601913771*^9}, {
   3.771334343273896*^9, 3.771334366362938*^9}, {3.77133473538422*^9, 
   3.77133473538422*^9}, {3.77279012166405*^9, 3.7727901415686827`*^9}, {
   3.77279440995434*^9, 3.7727944114504857`*^9}},
 CellLabel->
  "In[779]:=",ExpressionUUID->"d1f26434-ae84-41d2-b67b-d4283da07e0e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution of the Nonlinear System ", "Section",
 CellChangeTimes->{{3.7329351167568407`*^9, 3.7329351528354454`*^9}, {
   3.732935804441747*^9, 3.732935814395033*^9}, {3.732936005990015*^9, 
   3.7329360411311765`*^9}, {3.732937326517459*^9, 3.732937326673698*^9}, 
   3.7329374643318157`*^9, {3.732938048433488*^9, 3.7329380544179463`*^9}, 
   3.732938401078847*^9, 3.732949871546321*^9, {3.732950114596485*^9, 
   3.732950116049631*^9}, {3.7329599465556135`*^9, 3.7329599466494017`*^9}, {
   3.7329600626653337`*^9, 3.7329600628059583`*^9}, {3.7329740263434153`*^9, 
   3.732974068301512*^9}, {3.7329766984515896`*^9, 3.7329767185768676`*^9}, 
   3.733019569427712*^9, {3.733019657712632*^9, 3.733019660650178*^9}, {
   3.733039288244776*^9, 3.73303943041861*^9}, {3.7330394665440702`*^9, 
   3.7330394802786293`*^9}, {3.733052261224779*^9, 3.733052262130982*^9}, {
   3.7330524455241017`*^9, 3.733052466758814*^9}, 3.733210194209093*^9, {
   3.733234009911687*^9, 3.7332340271624126`*^9}, {3.733397762908857*^9, 
   3.7333977732224574`*^9}, 3.733401347305732*^9, 3.733473265507943*^9, {
   3.735441807812582*^9, 3.735441852106262*^9}, {3.770031566019047*^9, 
   3.770031585902921*^9}, {3.7700386631643705`*^9, 3.770038704703205*^9}, {
   3.7700389193953676`*^9, 3.7700389281613693`*^9}, {3.770211610753935*^9, 
   3.770211611841731*^9}},ExpressionUUID->"117444f3-4015-4c6b-9775-\
bd4baaf28235"],

Cell[CellGroupData[{

Cell["Iteration loop ", "Subsection",
 CellChangeTimes->{{3.770346621675571*^9, 3.7703467075355844`*^9}, {
   3.7703467635917234`*^9, 3.770346788790803*^9}, {3.7703468258482156`*^9, 
   3.7703468436407986`*^9}, {3.770346875321709*^9, 3.770346932992795*^9}, {
   3.7703469630589075`*^9, 3.7703470265110903`*^9}, {3.7703501882823205`*^9, 
   3.7703501944408636`*^9}, {3.770350531730981*^9, 3.770350626173993*^9}, {
   3.7703506753991385`*^9, 3.770350681080689*^9}, 3.770470056491517*^9, {
   3.7704702407239857`*^9, 3.7704702923340836`*^9}, 3.7704704397889614`*^9, 
   3.770522397290654*^9},ExpressionUUID->"ea35b083-86ca-43d0-a25a-\
8ee34a0f8628"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Assign", " ", "the", " ", "initial", " ", "guess", " ", "and", " ", "the",
     " ", "parameters"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", "lambda0", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lambda0", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{"0.", ",", 
       RowBox[{"{", 
        RowBox[{"i", " ", ",", " ", "1", ",", "nF"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", 
         RowBox[{"Nk", "-", "1"}]}], "}"}]}], "]"}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tau", "=", " ", "0.1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Normlam", " ", "=", " ", 
     RowBox[{"10", "tau"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"maxiter", " ", "=", " ", "10"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ell", " ", "=", " ", "0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"While", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Normlam", " ", ">", " ", "tau"}], " ", "&&", " ", 
      RowBox[{"ell", " ", "<", " ", "maxiter"}]}], ",", "\[IndentingNewLine]",
      "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Evaluate", " ", "the", " ", "approximate", " ", "solution", " ", "at", 
       " ", "the", " ", "previous", " ", "iteration", " ", "step"}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Clear", "[", "Ys", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Ys", " ", "=", " ", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Transpose", "[", "Mcoll0", "]"}], ".", 
           RowBox[{"lambda0", "[", 
            RowBox[{"[", "n", "]"}], "]"}]}], " ", ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nF"}], "}"}]}], "]"}], " ", "+", " ", 
        "Y0"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"ListPlot", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"TPoints", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"Ys", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", 
                RowBox[{"i", "-", "1"}]}], "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "nF"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "2", ",", "Ns"}], "}"}]}], "]"}], ",", 
         RowBox[{"Joined", " ", "\[Rule]", " ", "True"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", "\"\<Solution\>\""}]}], "]"}], "]"}],
       ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Evaluate", " ", "the", " ", "Jacobian", " ", "matrix", " ", "at", " ",
         "the", " ", "previous", " ", "iteration", " ", "step"}], " ", "*)"}],
       "\[IndentingNewLine]", 
      RowBox[{"JFNodes", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"JF", " ", "/.", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"y", "->", 
             RowBox[{"Ys", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "i"}], "]"}], "]"}]}], ",", 
            RowBox[{"z", "->", 
             RowBox[{"Ys", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", "i"}], "]"}], "]"}]}], ",", 
            RowBox[{"w", "->", 
             RowBox[{"Ys", "[", 
              RowBox[{"[", 
               RowBox[{"3", ",", "i"}], "]"}], "]"}]}]}], "}"}]}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Ns", "-", "1"}]}], "}"}]}], "]"}]}], ";", "\n", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
        "Construct", " ", "the", " ", "second", " ", "term", " ", "of", " ", 
         "the", " ", "Jacobian", " ", "matrix", " ", "J_G", " ", "by", " ", 
         "multipling", " ", "the", " ", "Jacobian", " ", "matrix", " ", "J_F",
          " ", "with", " ", "the", " ", "collocation", " ", "B"}], "-", 
        RowBox[{"spline", " ", "matrix"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", " ", 
      RowBox[{"JFblock", " ", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Outer", "[", 
          RowBox[{"Times", ",", 
           RowBox[{"JFNodes", "[", 
            RowBox[{"[", "i", "]"}], "]"}], ",", 
           RowBox[{"Mcoll0", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Nk", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"JJ", " ", "=", " ", 
       RowBox[{"ArrayFlatten", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"JFblock", ",", 
           RowBox[{"{", 
            RowBox[{"4", ",", "1", ",", "2", ",", "3"}], "}"}]}], "]"}], ",", 
         "2"}], "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Construct", " ", "the", " ", "Jacobian", " ", "matrix", " ", "J_G"}], 
       " ", "*)"}], "\n", "   ", 
      RowBox[{"Clear", "[", "Mcoll", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Mcoll", " ", "=", " ", 
       RowBox[{
        RowBox[{"KroneckerProduct", "[", 
         RowBox[{
          RowBox[{"IdentityMatrix", "[", "nF", "]"}], ",", 
          RowBox[{"Transpose", "[", "Mcoll1", "]"}]}], "]"}], "-", " ", 
        "JJ"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"Construct", " ", "the", " ", "known", " ", "term"}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"Clear", "[", "BG", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"BG", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"KroneckerProduct", "[", 
          RowBox[{
           RowBox[{"IdentityMatrix", "[", "nF", "]"}], ",", 
           RowBox[{"Transpose", "[", "Mcoll1", "]"}]}], "]"}], " ", ".", 
         RowBox[{"Flatten", "[", "lambda0", "]"}]}], "-", 
        RowBox[{"Flatten", "[", 
         RowBox[{"Transpose", "[", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"F", " ", "/.", " ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"y", "->", 
                RowBox[{"Ys", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "i"}], "]"}], "]"}]}], ",", 
               RowBox[{"z", "->", 
                RowBox[{"Ys", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "i"}], "]"}], "]"}]}], ",", 
               RowBox[{"w", "->", 
                RowBox[{"Ys", "[", 
                 RowBox[{"[", 
                  RowBox[{"3", ",", "i"}], "]"}], "]"}]}]}], "}"}]}], " ", 
            ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{"Ns", "-", "1"}]}], "}"}]}], "]"}], "]"}], "]"}]}]}], 
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Solve", " ", "the", " ", "linear", " ", "system", " ", "by", " ", 
        "the", " ", "least", " ", "squares", " ", "method"}], " ", "*)"}], 
      "\n", "  ", 
      RowBox[{"Clear", "[", "GamK", "]"}], ";", "\n", "  ", 
      RowBox[{"GamK", " ", "=", " ", 
       RowBox[{"LeastSquares", "[", 
        RowBox[{"Mcoll", ",", 
         RowBox[{"N", "[", "BG", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]",
       "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"Update", " ", "the", " ", "unknown", " ", "coefficients"}], 
       " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"Clear", "[", "lambda", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"lambda", "=", " ", 
       RowBox[{"lambda0", "-", " ", 
        RowBox[{"Partition", "[", 
         RowBox[{"GamK", ",", 
          RowBox[{"Nk", "-", "1"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Evaluate", " ", "the", " ", "infinity", " ", "norm", " ", "of", " ", 
        "the", " ", "relative", " ", "error"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"Normlam", " ", "=", " ", 
       RowBox[{
        RowBox[{"Norm", "[", 
         RowBox[{
          RowBox[{"lambda", "-", "lambda0"}], ",", "Infinity"}], "]"}], "/", 
        RowBox[{"Norm", "[", 
         RowBox[{"lambda", ",", "Infinity"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Update", " ", "the", " ", "iteration", " ", "counter", " ", "and", 
        " ", "the", " ", "privious", " ", "solution"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"ell", " ", "++"}], ";", "\[IndentingNewLine]", 
      RowBox[{"lambda0", " ", "=", " ", "lambda"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Print", " ", "the", " ", "relative", " ", "error", " ", "at", " ", 
        "iteration", " ", "ell"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<Iteration = \>\"", ",", "ell", ",", "\"\<   Norm = \>\"", ",", 
        "Normlam"}], "]"}], ";"}]}], "\n", "  ", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.770351410571428*^9, 3.770351421043413*^9}, {
   3.7703517214121213`*^9, 3.770351759189946*^9}, {3.770351934863375*^9, 
   3.770351953650074*^9}, {3.770352019463219*^9, 3.7703520898490677`*^9}, {
   3.7703522836573877`*^9, 3.7703522872406764`*^9}, {3.770352360566429*^9, 
   3.7703523980204277`*^9}, {3.7703524559864964`*^9, 3.770352489817569*^9}, {
   3.770352948443101*^9, 3.7703529533802056`*^9}, {3.770361369302343*^9, 
   3.7703614110104055`*^9}, 3.7703614420050077`*^9, 3.7704691023167953`*^9, {
   3.770470354696179*^9, 3.770470363089969*^9}, 3.7704705155228567`*^9, {
   3.7704706668063135`*^9, 3.7704706954506307`*^9}, {3.7704707325223265`*^9, 
   3.7704707800850816`*^9}, {3.7704708827050233`*^9, 
   3.7704709331514444`*^9}, {3.7704709797874594`*^9, 
   3.7704710205153933`*^9}, {3.770471099581667*^9, 3.7704711291306615`*^9}, 
   3.770471245432822*^9, {3.7704713774159346`*^9, 3.770471388096563*^9}, {
   3.7704714709558773`*^9, 3.7704714789318447`*^9}, {3.770471527939003*^9, 
   3.770471580174054*^9}, {3.7704716123735805`*^9, 3.7704716760154314`*^9}, {
   3.7704718180862293`*^9, 3.770471845180709*^9}, {3.770471876400611*^9, 
   3.7704718944243016`*^9}, {3.7704719472986555`*^9, 
   3.7704720751623964`*^9}, {3.770472135219715*^9, 3.770472135688403*^9}, {
   3.7705210593007393`*^9, 3.770521061676429*^9}, {3.7705212624424567`*^9, 
   3.7705212649579105`*^9}, {3.7705213712570987`*^9, 
   3.7705213713351865`*^9}, {3.7705214123775415`*^9, 
   3.7705214235041804`*^9}, {3.7705222007752485`*^9, 
   3.7705222056971054`*^9}, {3.7705222400619793`*^9, 
   3.7705222419444747`*^9}, {3.770522303048024*^9, 3.770522315148595*^9}, 
   3.7705223594621954`*^9, {3.7705224270488033`*^9, 3.7705224768022385`*^9}, 
   3.770525732695252*^9, 3.7705258701617603`*^9, {3.7705259836724577`*^9, 
   3.770525983813072*^9}, {3.7705260603241897`*^9, 3.7705260927383585`*^9}, {
   3.7705261500087433`*^9, 3.7705261543303137`*^9}, {3.7705264920168324`*^9, 
   3.770526492206952*^9}, {3.770722222640627*^9, 3.770722235363819*^9}, 
   3.7707223332497635`*^9, {3.7707223715203943`*^9, 3.7707223972004814`*^9}, {
   3.7707226190480323`*^9, 3.770722664689207*^9}, {3.7707227729727774`*^9, 
   3.7707227732852592`*^9}, {3.770722806471881*^9, 3.7707228094572525`*^9}, {
   3.770723282250353*^9, 3.7707232827659483`*^9}, {3.770723464541357*^9, 
   3.7707234650835066`*^9}, {3.7707236727123013`*^9, 
   3.7707236820053177`*^9}, {3.7707237148710175`*^9, 3.770723715058511*^9}, {
   3.7707240370480385`*^9, 3.7707240573310757`*^9}, {3.7707241793737946`*^9, 
   3.7707241798893833`*^9}, {3.7707249542010612`*^9, 3.770724979181274*^9}, {
   3.770725251873044*^9, 3.770725323358714*^9}, {3.77072537075235*^9, 
   3.7707253830730395`*^9}, {3.7707256135583134`*^9, 3.7707256211320295`*^9}, 
   3.7707265831940894`*^9, {3.770726750557396*^9, 3.7707267712332196`*^9}, {
   3.770726804978651*^9, 3.7707268060438027`*^9}, {3.77072685581367*^9, 
   3.7707268559543476`*^9}, {3.770727059708463*^9, 3.770727065351287*^9}, {
   3.770727150975031*^9, 3.7707271866576138`*^9}, 3.770727234008252*^9, {
   3.7707272641576953`*^9, 3.7707272888185234`*^9}, {3.7707273366211667`*^9, 
   3.770727337280096*^9}, {3.7707274082673426`*^9, 3.770727442112994*^9}, {
   3.7707275218945293`*^9, 3.770727849658677*^9}, 3.7707280830562925`*^9, {
   3.7707283337002864`*^9, 3.770728342141548*^9}, {3.7707283842255306`*^9, 
   3.7707283853660746`*^9}, {3.770728438412543*^9, 3.770728438801711*^9}, {
   3.7707286061654215`*^9, 3.7707286077590504`*^9}, {3.7707286577481766`*^9, 
   3.7707286653441114`*^9}, {3.7707291862200584`*^9, 3.77072925365481*^9}, {
   3.770729530924922*^9, 3.7707295389162636`*^9}, {3.770786092745978*^9, 
   3.770786098910427*^9}, {3.770786134228696*^9, 3.770786136575311*^9}, {
   3.770786201323223*^9, 3.7707862046200056`*^9}, {3.770790174556707*^9, 
   3.7707902039995375`*^9}, {3.770790764992797*^9, 3.770790832104978*^9}, {
   3.7707917564352765`*^9, 3.7707917629257393`*^9}, 3.7708105290161095`*^9, 
   3.770812141577197*^9, {3.7708137546120777`*^9, 3.7708137557737017`*^9}, {
   3.770813815948251*^9, 3.770813816166985*^9}, 3.770814008641986*^9, {
   3.770814054602103*^9, 3.7708140547583437`*^9}, 3.770814371869871*^9, 
   3.770988478963645*^9, 3.7709887149675317`*^9, {3.7709894616895742`*^9, 
   3.770989462986431*^9}, 3.7709895234787903`*^9, 3.770989555721337*^9, 
   3.7709897475292673`*^9, 3.770989780968524*^9, {3.7709898178429737`*^9, 
   3.7709898438149853`*^9}, {3.7709899322952766`*^9, 3.770989933732688*^9}, {
   3.770990093459852*^9, 3.7709901103348427`*^9}, {3.770990157946448*^9, 
   3.7709901596026654`*^9}, {3.7709901956626797`*^9, 3.7709901961626587`*^9}, 
   3.7709902692020435`*^9, 3.770990434074362*^9, {3.77099087429503*^9, 
   3.7709909039589014`*^9}, 3.7709910919974084`*^9, 3.7709917178634214`*^9, {
   3.771221423351287*^9, 3.771221425194977*^9}, {3.7712215618951263`*^9, 
   3.771221563006596*^9}, {3.771240389443454*^9, 3.771240416972219*^9}, {
   3.771240464123254*^9, 3.771240464748209*^9}, {3.771240495427806*^9, 
   3.7712407090373755`*^9}, 3.7712467201013966`*^9, 3.7712468129207726`*^9, {
   3.771247293613394*^9, 3.7712472998630238`*^9}, {3.771333982842415*^9, 
   3.7713340544157443`*^9}, 3.77133473539983*^9, {3.7713348449356265`*^9, 
   3.7713348753017273`*^9}, {3.771334920068021*^9, 3.7713350299304085`*^9}},
 CellLabel->
  "In[785]:=",ExpressionUUID->"b3aa18fa-2fa2-4eeb-b0d0-80b28b4aa4a8"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Evaluate the Numerical Solution ", "Section",
 CellChangeTimes->{{3.7332286151832633`*^9, 3.7332286257459106`*^9}, {
  3.770039899278011*^9, 3.770039905689377*^9}, {3.7700403229647694`*^9, 
  3.7700403271107035`*^9}, {3.7713350458862*^9, 
  3.771335049624329*^9}},ExpressionUUID->"bad7c561-eecb-4dc3-a3a5-\
7bd75281db6a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"B1sint", ",", "B1s"}], "]"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   StyleBox[
    RowBox[{
     StyleBox["(", "Text"], 
     StyleBox["*", "Input"]}]], 
   StyleBox[" ", "Input"], 
   StyleBox[
    RowBox[{
    "Points", " ", "where", " ", "to", " ", "evaluate", " ", "the", " ", 
     "numerical", " ", "solution"}], "Input"], 
   StyleBox[" ", "Input"], 
   StyleBox["*)", "Input"]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"h2", " ", "=", " ", 
    FractionBox[
     RowBox[{"h", " "}], "4"]}], ";"}], 
  "               "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Nr", " ", "=", " ", 
    RowBox[{
     FractionBox["T", "h2"], "+", "1"}]}], " ", ";"}], 
  "    "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Tval", " ", "=", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"i", " ", "h2"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", 
        RowBox[{"Nr", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Function", " ", "basis", " ", "on", " ", "the", " ", "evaluation", " ", 
    "points"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"B1sint", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"N", "[", 
      RowBox[{"B1", "[", " ", 
       RowBox[{
        FractionBox[
         RowBox[{"Tval", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "h"], "-", "k"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "Nr"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", 
       RowBox[{"Nkint", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"B1s", " ", "=", " ", 
    RowBox[{"Transpose", "[", "B1sint", "]"}]}], ";"}], "\[IndentingNewLine]",
   "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Print", " ", "the", " ", "numerical", " ", "solution"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", "Yh", "]"}], "\n", 
 RowBox[{
  RowBox[{"Yh", " ", "=", " ", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Transpose", "[", "B1s", "]"}], ".", 
       RowBox[{"lambda", "[", 
        RowBox[{"[", "n", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", "nF"}], "}"}]}], "]"}], "+", "Y0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Tval", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"Yh", "[", 
        RowBox[{"[", 
         RowBox[{"k", ",", "i"}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", "nF"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "Nr"}], "}"}]}], "]"}], ",", 
   RowBox[{"Joined", " ", "\[Rule]", " ", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "\n"}], "Input",
 CellChangeTimes->{
  3.622552237161689*^9, 3.622552278442891*^9, {3.6225523283958826`*^9, 
   3.6225524261769867`*^9}, {3.622552478145616*^9, 3.622552483723732*^9}, 
   3.622552543364295*^9, {3.62256382606121*^9, 3.6225638972026663`*^9}, {
   3.622563949265804*^9, 3.622563977297432*^9}, {3.622564064642305*^9, 
   3.622564102752142*^9}, {3.6225644000996037`*^9, 3.6225644010683765`*^9}, {
   3.6225644361156273`*^9, 3.6225644594753675`*^9}, {3.6225645059446764`*^9, 
   3.6225645184448013`*^9}, {3.62256457653926*^9, 3.6225647609165354`*^9}, {
   3.6225648245267935`*^9, 3.622564905043214*^9}, 3.622564966950308*^9, {
   3.622565004513296*^9, 3.622565043404416*^9}, {3.6226167160513277`*^9, 
   3.622616716692034*^9}, {3.622616932302985*^9, 3.6226169477249565`*^9}, 
   3.6226170021160617`*^9, {3.6228941510271034`*^9, 3.622894167058446*^9}, {
   3.6228942018243675`*^9, 3.622894285840732*^9}, {3.6228944202596426`*^9, 
   3.622894424775295*^9}, {3.6228946028858614`*^9, 3.6228946056827617`*^9}, 
   3.622895579160679*^9, 3.622895671833474*^9, 3.622895837163191*^9, {
   3.623045122469674*^9, 3.6230451723293204`*^9}, 3.6230457426299334`*^9, {
   3.623470420812352*^9, 3.6234704243593397`*^9}, {3.623470683226535*^9, 
   3.6234707008830347`*^9}, {3.6234708914316435`*^9, 3.62347091471307*^9}, {
   3.6234713127325087`*^9, 3.623471335045208*^9}, {3.623471833049987*^9, 
   3.623471860815838*^9}, {3.6234720970682344`*^9, 3.623472113568367*^9}, {
   3.6234732275476217`*^9, 3.623473228219487*^9}, 3.623568344239814*^9, 
   3.6235688107702265`*^9, 3.6235764477529025`*^9, 3.623576535502465*^9, 
   3.6235766015336246`*^9, 3.623576645377178*^9, {3.6237562629655*^9, 
   3.6237562858248353`*^9}, 3.623756411074013*^9, {3.624890019092003*^9, 
   3.6248900467954006`*^9}, {3.6248905335653577`*^9, 3.624890535440315*^9}, {
   3.624962378184225*^9, 3.624962384684263*^9}, 3.626004371637586*^9, 
   3.6260045623882227`*^9, 3.6260049148581047`*^9, {3.6260615731343203`*^9, 
   3.626061578509254*^9}, {3.6265962749628086`*^9, 3.626596283416113*^9}, {
   3.6265964806377954`*^9, 3.626596481278427*^9}, 3.6265965364198246`*^9, 
   3.6265970421143804`*^9, 3.6265976356552887`*^9, 3.6366884998626537`*^9, {
   3.636688820350551*^9, 3.6366888448664446`*^9}, 3.6366896324421053`*^9, {
   3.6366897085054436`*^9, 3.6366897109273443`*^9}, 3.636689777631201*^9, {
   3.6366908283699517`*^9, 3.6366908299480925`*^9}, {3.636691050747398*^9, 
   3.636691053216173*^9}, {3.7328717469476223`*^9, 3.73287178696546*^9}, 
   3.7328718577811136`*^9, {3.7328719243320427`*^9, 3.7328719705669994`*^9}, 
   3.73287207732065*^9, {3.7328721214469175`*^9, 3.7328721264781713`*^9}, {
   3.7328723561126738`*^9, 3.732872380847044*^9}, 3.732872618856084*^9, 
   3.732872876082345*^9, 3.7328729109578023`*^9, 3.732937442018961*^9, 
   3.732937482347664*^9, {3.7329376822253428`*^9, 3.732937689131744*^9}, 
   3.732947817674651*^9, {3.732948068574293*^9, 3.7329480688711195`*^9}, {
   3.7329490314320107`*^9, 3.732949033150733*^9}, {3.732950045158044*^9, 
   3.7329500468143444`*^9}, 3.7329505878998404`*^9, {3.732950941308674*^9, 
   3.7329509706028337`*^9}, {3.7330212178468676`*^9, 
   3.7330212207219095`*^9}, {3.733208802947728*^9, 3.733208807181102*^9}, {
   3.7332295592454867`*^9, 3.733229608614363*^9}, {3.7332296670683265`*^9, 
   3.733229668052673*^9}, {3.7332297266472626`*^9, 3.733229835336356*^9}, {
   3.733230460470253*^9, 3.7332304719235487`*^9}, {3.7332309582117357`*^9, 
   3.7332310415098658`*^9}, {3.733231084901043*^9, 3.733231093651163*^9}, 
   3.733231158589592*^9, {3.7332352010644827`*^9, 3.7332352393464146`*^9}, {
   3.733243780643161*^9, 3.7332437924089675`*^9}, {3.7336576957214513`*^9, 
   3.7336577018309126`*^9}, {3.7661991180639486`*^9, 3.76619912321986*^9}, {
   3.766199456498666*^9, 3.7661994594516125`*^9}, {3.7664859309655547`*^9, 
   3.76648594902682*^9}, {3.7664859977147446`*^9, 3.766486001669407*^9}, {
   3.7664913958442044`*^9, 3.766491528269142*^9}, {3.7664917212205553`*^9, 
   3.7664917216423655`*^9}, {3.7700399112529354`*^9, 3.770040115425942*^9}, {
   3.770040159946664*^9, 3.7700401630355625`*^9}, {3.770040350459423*^9, 
   3.770040390186602*^9}, {3.770040428394238*^9, 3.770040438036576*^9}, {
   3.770040472580361*^9, 3.7700404745646534`*^9}, {3.7701134545473475`*^9, 
   3.770113463283819*^9}, {3.770113539618408*^9, 3.770113545027285*^9}, {
   3.7701137224686623`*^9, 3.7701137229999104`*^9}, {3.7704686871200852`*^9, 
   3.7704686872919474`*^9}, {3.770469220959552*^9, 3.770469228150756*^9}, 
   3.770469283306863*^9, {3.7704693783838177`*^9, 3.770469444215914*^9}, {
   3.770810197898444*^9, 3.7708102028098516`*^9}, {3.7712408322407675`*^9, 
   3.7712408396732445`*^9}, 3.7712409971502705`*^9, {3.7712410279405365`*^9, 
   3.7712410397874365`*^9}, {3.771241211912498*^9, 3.771241316571826*^9}, {
   3.77124141865202*^9, 3.7712414796296005`*^9}, {3.7712416175186563`*^9, 
   3.7712416337075853`*^9}, {3.7712417005215387`*^9, 
   3.7712417089126015`*^9}, {3.7712417992759056`*^9, 
   3.7712417997243137`*^9}, {3.7712460763650894`*^9, 
   3.7712461151829686`*^9}, {3.77124615114589*^9, 3.7712461598973207`*^9}, 
   3.7712461946796913`*^9, {3.771246283068698*^9, 3.7712463107761793`*^9}, {
   3.771246602000682*^9, 3.771246612705907*^9}, 3.7713340807638245`*^9, {
   3.7713342516974525`*^9, 3.771334303968133*^9}, {3.7713350626166477`*^9, 
   3.771335091382801*^9}, {3.7727902669760036`*^9, 3.772790349081093*^9}, {
   3.772794432325557*^9, 3.7727944712213326`*^9}},
 CellLabel->
  "In[792]:=",ExpressionUUID->"d1e99bc4-ac7b-45d6-89aa-a3d7d0a046d3"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1263, 637},
WindowMargins->{{-8, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, 32000},
PrintingOptions->{"Magnification"->1.,
"PageSize"->{841.92, 595.3199999999999},
"PaperOrientation"->"Landscape",
"PaperSize"->{841.92, 595.1999999999999},
"PrintingMargins"->{{72.00000078, 72.00000078}, {54.000000584999995`, \
54.000000584999995`}}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowSelection->True,
FrontEndVersion->"12.0 for Microsoft Windows (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 656, 11, 156, "Title",ExpressionUUID->"08bc54e3-0efd-4181-97c3-954ef553d170"],
Cell[1238, 35, 635, 14, 209, "Subsection",ExpressionUUID->"8eb67413-4316-4e7e-936e-ebd3c432a647"],
Cell[CellGroupData[{
Cell[1898, 53, 315, 5, 53, "Section",ExpressionUUID->"3346d938-10ac-476f-a592-e49966ce9807"],
Cell[CellGroupData[{
Cell[2238, 62, 418, 9, 94, "Subsubsection",ExpressionUUID->"7f7fc801-0ef6-44ed-b035-2de4165f9d0c"],
Cell[2659, 73, 8076, 155, 492, "Input",ExpressionUUID->"c4a28490-943e-4e01-87fd-b4d114987e79"]
}, Open  ]]
}, Open  ]],
Cell[10762, 232, 162, 3, 67, "Section",ExpressionUUID->"38b1aa6d-e12a-4452-a7d9-1ae60f60a8a5"],
Cell[CellGroupData[{
Cell[10949, 239, 310, 5, 41, "Section",ExpressionUUID->"41864846-420c-4a4e-9165-4d49b6ef26f0"],
Cell[11262, 246, 1112, 26, 105, "Input",ExpressionUUID->"5efb9206-c999-44e4-a8f0-54bc292608ac"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12411, 277, 297, 4, 55, "Section",ExpressionUUID->"866dc4bf-d564-4d29-902f-491975a1543c"],
Cell[12711, 283, 1005, 24, 67, "Input",ExpressionUUID->"6f683e80-cf87-47fd-a899-0838b9073d9a"]
}, Open  ]],
Cell[13731, 310, 201, 3, 67, "Section",ExpressionUUID->"31331755-3b67-4704-873b-63754bb288ae"],
Cell[CellGroupData[{
Cell[13957, 317, 433, 7, 69, "Section",ExpressionUUID->"b7159cb9-ee6a-4f86-800e-9f3cea1d682c"],
Cell[14393, 326, 2222, 53, 126, "Input",ExpressionUUID->"42c55258-8420-42df-a3a2-0a931cffb3c8"],
Cell[CellGroupData[{
Cell[16640, 383, 1011, 17, 53, "Subsection",ExpressionUUID->"ffb41342-358e-4adf-b8d9-dc4b8a3bf2d0"],
Cell[17654, 402, 2295, 58, 107, "Input",ExpressionUUID->"fad9c053-bf9e-41a8-b4ef-bb3deccf2349"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19998, 466, 202, 3, 67, "Section",ExpressionUUID->"cc25ddf5-3300-402a-a06c-49166cd17313"],
Cell[20203, 471, 12953, 199, 335, "Input",ExpressionUUID->"a6f0c34b-7c15-4f53-8b77-46c3cc0cd92c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33193, 675, 1419, 20, 67, "Section",ExpressionUUID->"f9eb6e00-eb9e-40e6-a54d-2b6d716dc661"],
Cell[34615, 697, 3493, 59, 181, "Input",ExpressionUUID->"f9441561-30dc-4df7-90e6-9d34f5b66484"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38145, 761, 395, 6, 67, "Section",ExpressionUUID->"648c2988-bddb-42f7-b1ae-eafe61a80c68"],
Cell[38543, 769, 5532, 93, 181, "Input",ExpressionUUID->"67e2f0cb-1bd8-4ee3-b2e4-99af1335f701"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44112, 867, 324, 6, 67, "Section",ExpressionUUID->"b86d5c1c-d494-444b-bf64-daac74834407"],
Cell[44439, 875, 3291, 71, 238, "Input",ExpressionUUID->"d1f26434-ae84-41d2-b67b-d4283da07e0e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47767, 951, 1402, 19, 67, "Section",ExpressionUUID->"117444f3-4015-4c6b-9775-bd4baaf28235"],
Cell[CellGroupData[{
Cell[49194, 974, 646, 9, 53, "Subsection",ExpressionUUID->"ea35b083-86ca-43d0-a25a-8ee34a0f8628"],
Cell[49843, 985, 14915, 302, 941, "Input",ExpressionUUID->"b3aa18fa-2fa2-4eeb-b0d0-80b28b4aa4a8"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[64807, 1293, 327, 5, 67, "Section",ExpressionUUID->"bad7c561-eecb-4dc3-a3a5-7bd75281db6a"],
Cell[65137, 1300, 8620, 172, 370, "Input",ExpressionUUID->"d1e99bc4-ac7b-45d6-89aa-a3d7d0a046d3"]
}, Open  ]]
}, Open  ]]
}
]
*)

